@@ -2,7 +2,6 @@ import asyncio  # noqa
 import logging
 from asyncio import AbstractEventLoop
 from typing import (
-    Any,
     MutableMapping,
     Union,
 )
@@ -55,7 +54,7 @@ class RPCAsyncClient(RPCAsyncClientProtocol, AsyncConnector, MessageConverter):
 
     async def rpc_call(
             self,
-            body: Any,
+            body: dict,
             queue_name,
             timeout: TimeoutType,
             expiration: bool = True,
@@ -69,7 +68,9 @@ class RPCAsyncClient(RPCAsyncClientProtocol, AsyncConnector, MessageConverter):
             future = self.loop.create_future()
             self.futures[correlation_id] = future
 
-            expiration: str | None = (expiration and str(timeout)) or None
+            expiration: str | None = (expiration and timeout) or None
+
+            body = self.convert_dict_to_bytes(obj=body)
 
             await channel.default_exchange.publish(
                 message=Message(
@@ -82,7 +83,10 @@ class RPCAsyncClient(RPCAsyncClientProtocol, AsyncConnector, MessageConverter):
                 routing_key=queue_name,
                 timeout=timeout,
             )
-            return await future
+            try:
+                return await asyncio.wait_for(future, timeout)
+            except asyncio.TimeoutError:
+                return None
 
 
 class RPCSyncClient(RPCSyncClientProtocol, Connector, MessageConverter):
@@ -112,7 +116,7 @@ class RPCSyncClient(RPCSyncClientProtocol, Connector, MessageConverter):
     def rpc_call(
             self,
             routing_key,
-            body,
+            body: dict,
             timeout: TimeoutType,
             expiration: bool = True,
     ):
@@ -125,6 +129,8 @@ class RPCSyncClient(RPCSyncClientProtocol, Connector, MessageConverter):
 
             expiration: str | None = (expiration and str(timeout)) or None
 
+            body = self.convert_dict_to_bytes(obj=body)
+
             channel.basic_publish(
                 exchange=self._exchange,
                 routing_key=routing_key,
